==> dl.php?src=linea21_1_7.zip: linea21/library/scripts/languages/zh-cn.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "您没有被授权使用文件管理器。", 
    "DIRECTORY_ALREADY_EXISTS": "目录'%s'已经存在。", 
    "DIRECTORY_NOT_EXIST": "目录%s不存在。", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_RENAMING_DIRECTORY": "发生错误当重新命名的目录%s到%s。", 
    "ERROR_RENAMING_FILE": "发生错误当重新命名的文件%s到%s。", 
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "文件%s不存在。", 
    "INVALID_ACTION": "无效的action.", 
    "INVALID_DIRECTORY_OR_FILE": "无效的目录或文件。", 
    "INVALID_FILE_TYPE": "File upload is not allowed.", 
    "INVALID_FILE_UPLOAD": "无效的文件上传。", 
    "INVALID_VAR": "无效变量 %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "语言文件未找到。", 
    "MODE_ERROR": "模式错误.", 
    "UNABLE_TO_CREATE_DIRECTORY": "无法创建目录%s", 
    "UNABLE_TO_OPEN_DIRECTORY": "无法打开目录%s。", 
    "UPLOAD_FILES_SMALLER_THAN": "请只上传文件小于%s的", 
    "UPLOAD_IMAGES_ONLY": "请上传只有图像，不支持其他文件。", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "请上传类型仅限JPEG图像，GIF或PNG格式。", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "取消", 
    "confirmation_delete": "你确定要删除这个文件吗？", 
    "could_not_retrieve_folder": "无法取得文件夹的内容。", 
    "create_folder": "创建文件夹", 
    "created": "创建", 
    "current_folder": "当前文件夹: ", 
    "default_foldername": "我的文件夹", 
    "del": "删除", 
    "dimensions": "尺寸", 
    "download": "下载", 
    "fck_select_integration": "'选择'功能只用于集成FCKeditor的。", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "gotoroot": "根文件夹", 
    "grid_view": "切换到网格视图.", 
    "kb": "kb", 
    "list_view": "切换到列表视图.", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "修改", 
    "move": "Move to ...", 
    "name": "名称", 
    "new_filename": "输入一个文件的新名称", 
    "new_folder": "新建文件夹", 
    "no": "否", 
    "no_foldername": "没有提供文件夹的名称。", 
    "parentfolder": "父文件夹", 
    "prompt_foldername": "请输入新文件夹的名称", 
    "rename": "重命名", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "选择", 
    "select_from_left": "从左侧选择一个条目。", 
    "size": "大小", 
    "successful_added_file": "新文件添加成功。", 
    "successful_added_folder": "新建文件夹添加成功。", 
    "successful_delete": "删除成功。", 
    "successful_moved": "Move successful.", 
    "successful_rename": "重命名成功。", 
    "upload": "上传", 
    "yes": "是"
}

==> dl.php?src=linea21_2_8_0.zip: linea21/library/scripts/languages/zh-cn.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "您没有被授权使用文件管理器。", 
    "DIRECTORY_ALREADY_EXISTS": "目录'%s'已经存在。", 
    "DIRECTORY_NOT_EXIST": "目录%s不存在。", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_CREATING_ZIP": "Error creating Zip archive", 
    "ERROR_OPENING_FILE": "Error opening file.", 
    "ERROR_RENAMING_DIRECTORY": "发生错误当重新命名的目录%s到%s。", 
    "ERROR_RENAMING_FILE": "发生错误当重新命名的文件%s到%s。", 
    "ERROR_REPLACING_FILE": "Please, provide a file having the following extension :", 
    "ERROR_SAVING_FILE": "Error saving file.", 
    "ERROR_UPLOADING_FILE": "Error uploading file.", 
    "ERROR_WRITING_PERM": "You don't have write permissions on that file.", 
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "文件%s不存在。", 
    "INVALID_ACTION": "无效的action.", 
    "INVALID_DIRECTORY_OR_FILE": "无效的目录或文件。", 
    "INVALID_FILE_TYPE": "File type is not allowed.", 
    "INVALID_FILE_UPLOAD": "无效的文件上传。", 
    "INVALID_VAR": "无效变量 %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "语言文件未找到。", 
    "MODE_ERROR": "模式错误.", 
    "NOT_ALLOWED": "You are not allowed to process this action", 
    "NOT_ALLOWED_SYSTEM": "System permissions do not allow you to perform this action", 
    "UNABLE_TO_CREATE_DIRECTORY": "无法创建目录%s", 
    "UNABLE_TO_OPEN_DIRECTORY": "无法打开目录%s。", 
    "UPLOAD_FILES_SMALLER_THAN": "请只上传文件小于%s的", 
    "UPLOAD_IMAGES_ONLY": "请上传只有图像，不支持其他文件。", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "请上传类型仅限JPEG图像，GIF或PNG格式。", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "取消", 
    "close": "Close", 
    "confirmation_delete": "你确定要删除这个文件吗？", 
    "copied": "URL copied !", 
    "copy_to_clipboard": "Copy to Clipboard", 
    "could_not_retrieve_folder": "无法取得文件夹的内容。", 
    "create_folder": "创建文件夹", 
    "created": "创建", 
    "current_folder": "当前文件夹: ", 
    "default_foldername": "我的文件夹", 
    "del": "删除", 
    "dimensions": "尺寸", 
    "download": "下载", 
    "dz_dictDefaultMessage": "Drop files here to upload", 
    "dz_dictFallbackMessage": "Your browser does not support drag'n'drop file uploads.", 
    "dz_dictInvalidFileType": "You can't upload files of this type.", 
    "dz_dictMaxFilesExceeded": "Only %s simultaneous uploads are allowed.", 
    "edit": "Edit file", 
    "fck_select_integration": "'选择'功能只用于集成FCKeditor的。", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "gotoroot": "根文件夹", 
    "grid_view": "切换到网格视图.", 
    "help_move": "The use of '../' is forbidden. You can access root folder by using '/'.", 
    "items": "items", 
    "kb": "kb", 
    "list_view": "切换到列表视图.", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "修改", 
    "move": "Move to ...", 
    "name": "名称", 
    "new_filename": "输入一个文件的新名称", 
    "new_folder": "新建文件夹", 
    "no": "否", 
    "no_foldername": "没有提供文件夹的名称。", 
    "parentfolder": "父文件夹", 
    "prompt_foldername": "请输入新文件夹的名称", 
    "quit_editor": "Quit editor", 
    "rename": "重命名", 
    "replace": "Replace file", 
    "save": "Save", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "选择", 
    "select_from_left": "从左侧选择一个条目。", 
    "size": "大小", 
    "successful_added_file": "新文件添加成功。", 
    "successful_added_folder": "新建文件夹添加成功。", 
    "successful_delete": "删除成功。", 
    "successful_edit": "Content update successful.", 
    "successful_moved": "Move successful.", 
    "successful_rename": "重命名成功。", 
    "successful_replace": "File replacement successful.", 
    "support_fm": "Filemanager is a free software, please support !", 
    "upload": "上传", 
    "version": "version", 
    "yes": "是"
}
